/*
 * Copyright (C) 2006-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.mail;

import com.funambol.util.Log;

import jmunit.framework.cldc10.AssertionFailedException;
import jmunit.framework.cldc10.TestCase;

/**
 * A JMUnit test class to check the functionality of the MIME parser
 */
public class MIMEProcessorTest extends TestCase {

    /**
     * The constructor. Please refer to the JMUnit documentation
     */
    public MIMEProcessorTest() {
        super(6, "MIMEProcessorTest");
        Log.setLogLevel(Log.DEBUG);
    }

    /**
     * Test of parseMailMessage method, of class com.funambol.mail.MIMEProcessor
     */
    public void testparseMailMessage(String expectedResult, String contentType)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        assertEquals(expectedResult, result.getContentType());
    }

    /**
     * Test of parseMailMessage method, of class com.funambol.mail.MIMEProcessor
     */
    public void testparseMailMessage2(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        try {
            assertEquals(expectedResult, result.getFrom().getEmail());// getName()
        } catch (MailException e) {
            e.printStackTrace();
        }
    }

    /**
     * Test of parseMailMessage method, of class com.funambol.mail.MIMEProcessor
     */
    public void testparseMailMessage3(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        assertEquals(expectedResult, result.getMessageId());
    }

    /**
     * @param expectedResult
     *            The content transfer encoding of the first body part
     *            (quoted-printable)
     */
    public void testparseMailMessage4(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        Multipart mp = (Multipart)result.getContent();
        BodyPart bp = mp.getBodyPart(0);
        String cte = bp.getHeader("content-transfer-encoding");

        assertEquals(expectedResult, cte);
    }

    /**
     * @param expectedResult
     *            The content type of the first body part (text/plain)
     */
    public void testparseMailMessage5(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        assertEquals(expectedResult, ((Multipart)result.getContent())
                .getBodyPart(0).getHeader("content-type"));
    }

    /**
     * @param expectedResult
     *            The content type of the second body part
     *            (application/x-pkcs7-signature)
     */
    public void testparseMailMessage6(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        
        
        assertEquals(expectedResult, ((Multipart)result.getContent())
                .getBodyPart(1).getHeader("content-type"));
    }

    /**
     * @see jmunit.framework.cldc11.TestCase#setUp()
     */
    public void setUp() {
    }

    /**
     * @see jmunit.framework.cldc11.TestCase#tearDown()
     */
    public void tearDown() {
    }

    /**
     * @see jmunit.framework.cldc11.TestCase#test(int)
     */
    public void test(int testNumber) throws Throwable {
        switch (testNumber) {

        case 0:
            testparseMailMessage("multipart/mixed", "content-type");
            break;

        case 1:
            testparseMailMessage2("giuseppe.garibaldi@platsch.com");
            break;

        case 2:
            testparseMailMessage3("c96b5e8f0611070513o3ec40fcbt24fdfed718856167@mail.gmail.com");
            break;
            
        case 3:
            testparseMailMessage4("quoted-printable");
            break;
            
        case 4:
            testparseMailMessage5("text/plain");
            break;
            
        case 5:
            testparseMailMessage6("image/jpeg");// application/octet-stream
            break;

        default:
            break;
        }
    }
}
