/*
 * Copyright (C) 2006-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.mail;

import jmunit.framework.cldc10.AssertionFailedException;
import jmunit.framework.cldc10.TestCase;

public class MessageFlagsTest extends TestCase {

    /**
     * The object to be populated with the unit testing
     */
    private MessageFlags flags = null;

    /**
     * Test of clearFlags method, of class MessageFlags
     */
    public void testclearFlags(MessageFlags flags)
            throws AssertionFailedException {
        System.out.println("clearFlags");
        flags.clearFlags();

        assertFalse(flags.isSet(flags.ANSWERED));
        assertFalse(flags.isSet(flags.FORWARDED));
        assertFalse(flags.isSet(flags.OPENED));
        assertFalse(flags.isSet(flags.DRAFT));
        assertFalse(flags.isSet(flags.FLAGGED));
        assertFalse(flags.isSet(flags.DELETED));
        assertFalse(flags.isSet(flags.TX_ERROR));
        assertFalse(flags.isSet(flags.TX_SENDING));
        assertFalse(flags.isSet(flags.TX_SENT));
    }

    /**
     * Test of setFlag method, of class MessageFlags
     */
    public void testsetFlag(MessageFlags flags, int flag)
            throws AssertionFailedException {
        System.out.println("setFlag");

        flags.setFlag(flag, true);

        assertTrue(flags.isSet(flag));
    }


    /**
     * Test of isSet method, of class MessageFlags
     */
    public void testisSet(MessageFlags flags, int flag)
            throws AssertionFailedException {
        System.out.println("isSet");
        
        boolean expectedResult = true;
        boolean result = flags.isSet(flag);

        assertTrue(expectedResult == result);
    }


    public MessageFlagsTest() {
        super(19, "MessageFlagsTest");
    }


    public void setUp() {
        flags = new MessageFlags();

        flags.setFlags(flags.ANSWERED|flags.FORWARDED|flags.OPENED
                       |flags.DRAFT|flags.FLAGGED|flags.DELETED
                       |flags.TX_SENDING|flags.TX_SENT|flags.TX_ERROR);
    }


    public void tearDown() {
    }


    public void test(int testNumber) throws Throwable {
        switch (testNumber) {
            case 0:
                testclearFlags(flags);
                break;
            case 1:
                testsetFlag(flags, flags.DELETED);
                break;
            case 2:
                testsetFlag(flags, flags.DRAFT);
                break;
            case 3:
                testsetFlag(flags, flags.FLAGGED);
                break;
            case 4:
                testsetFlag(flags, flags.FORWARDED);
                break;
            case 5:
                testsetFlag(flags, flags.OPENED);
                break;
            case 6:
                testsetFlag(flags, flags.ANSWERED);
                break;
            case 7:
                testsetFlag(flags, flags.TX_ERROR);
                break;
            case 8:
                testsetFlag(flags, flags.TX_SENDING);
                break;
            case 9:
                testsetFlag(flags, flags.TX_SENT);
                break;
            case 10:
                testisSet(flags, flags.DELETED);
                break;
            case 11:
                testisSet(flags, flags.DRAFT);
                break;
            case 12:
                testisSet(flags, flags.FLAGGED);
                break;
            case 13:
                testisSet(flags, flags.FORWARDED);
                break;
            case 14:
                testisSet(flags, flags.OPENED);
                break;
            case 15:
                testisSet(flags, flags.ANSWERED);
                break;    
            case 16:
                testisSet(flags, flags.TX_ERROR);
                break;
            case 17:
                testisSet(flags, flags.TX_SENDING);
                break;
            case 18:
                testisSet(flags, flags.TX_SENT);
                break;
                            
            default:
                break;
        }
    }
}
